[][src]Enum sciter::graphics::LINE_CAP

#[repr(C)]pub enum LINE_CAP {
    BUTT,
    SQUARE,
    ROUND,
}

Line drawing cap mode.

Variants

BUTT

The ends of lines are squared off at the endpoints.

SQUARE

The ends of lines are squared off by adding a box with an equal width and half the height of the line's thickness.

ROUND

The ends of lines are rounded.