[−][src]Struct sciter::graphics::Path
Graphics path object.
Implementations
impl Path[src]
pub fn create() -> Result<Path>[src]
Create a new empty path.
pub fn new() -> Result<Path>[src]
Use Path::create() instead.
Create a new empty path.
pub fn close(&mut self) -> Result<()>[src]
Close the current path/figure.
pub fn move_to(&mut self, point: Pos, is_relative: bool) -> Result<&mut Path>[src]
Move the current drawing path position to x,y.
If is_relative is true then the specified coordinates are interpreted as deltas from the current path position.
pub fn line_to(&mut self, point: Pos, is_relative: bool) -> Result<&mut Path>[src]
Draw a line and move the current drawing path position to x,y.
If is_relative is true then the specified coordinates are interpreted as deltas from the current path position.
pub fn arc_to(
&mut self,
xy: Pos,
angle: Angle,
rxy: Pos,
is_large: bool,
is_clockwise: bool,
is_relative: bool
) -> Result<&mut Path>[src]
&mut self,
xy: Pos,
angle: Angle,
rxy: Pos,
is_large: bool,
is_clockwise: bool,
is_relative: bool
) -> Result<&mut Path>
Draw an arc.
pub fn quadratic_curve_to(
&mut self,
control: Pos,
end: Pos,
is_relative: bool
) -> Result<&mut Path>[src]
&mut self,
control: Pos,
end: Pos,
is_relative: bool
) -> Result<&mut Path>
Draw a quadratic Bézier curve.
If is_relative is true then the specified coordinates are interpreted as deltas from the current path position.
pub fn bezier_curve_to(
&mut self,
control1: Pos,
control2: Pos,
end: Pos,
is_relative: bool
) -> Result<&mut Path>[src]
&mut self,
control1: Pos,
control2: Pos,
end: Pos,
is_relative: bool
) -> Result<&mut Path>
Draw a cubic Bézier curve.
If is_relative is true then the specified coordinates are interpreted as deltas from the current path position.