[][src]Struct sciter::graphics::Text

pub struct Text(_);

Text layout object.

Implementations

impl Text[src]

pub fn create(e: &Element, text: &str) -> Result<Text>[src]

Create a text layout object on top of a host element.

pub fn with_class(e: &Element, text: &str, class: &str) -> Result<Text>[src]

Create a text layout object on top of a host element with the specified class attribute.

pub fn with_style(e: &Element, text: &str, styles: &str) -> Result<Text>[src]

Create a text layout object on top of a host element with the specified style attribute.

pub fn set_box(&mut self, size: Size) -> Result<()>[src]

Sets the box width and height of the text object.

pub fn get_metrics(&self) -> Result<TextMetrics>[src]

Returns metrics of the text layout object.