[−][src]Struct sciter::graphics::TextMetrics
Metrics of a text layout object.
Fields
min_width: DimMinimum width, is a width of the widest word (non-breakable sequence) in the text.
max_width: DimMaximum width, is the width of the text without wrapping.
If the text contains new line sequences then function returns width of widest string.
height: DimComputed height of the Text object and box height.
ascent: Dimdescent: Dimlines: u32Mumber of lines in text layout.
To get meaningful values you should set width of the text layout object
(with Text.set_box, for example).