#[repr(C)]pub enum VALUE_TYPE {
Show 23 variants
T_UNDEFINED = 0,
T_NULL = 1,
T_BOOL = 2,
T_INT = 3,
T_FLOAT = 4,
T_STRING = 5,
T_DATE = 6,
T_CURRENCY = 7,
T_LENGTH = 8,
T_ARRAY = 9,
T_MAP = 10,
T_FUNCTION = 11,
T_BYTES = 12,
T_OBJECT = 13,
T_DOM_OBJECT = 14,
T_RESOURCE = 15,
T_RANGE = 16,
T_DURATION = 17,
T_ANGLE = 18,
T_COLOR = 19,
T_ENUM = 20,
T_ASSET = 21,
T_UNKNOWN = 22,
}Expand description
Type identifier of the value.
Variants
T_UNDEFINED = 0
Just undefined, the data is zero, the unit can be UT_NOTHING.
T_NULL = 1
Explicit null type, the rest fields are zero.
T_BOOL = 2
Data is 1 or 0; units can be used but unknown.
T_INT = 3
Data is an integer; units can be used but unknown.
T_FLOAT = 4
Data is a double float; units can be used but unknown.
T_STRING = 5
Data is a Sciter internal string, unit is [VALUE_UNIT_TYPE_STRING].
T_DATE = 6
Data is FILETIME (64-bit value in 100ns since the unix epoch).
No unit is stored but is_utc boolean is used during creation.
T_CURRENCY = 7
Data is a 64-bit number, no units.
T_LENGTH = 8
Data is a float (but can be constructed from an int), unit is [VALUE_UNIT_TYPE_LENGTH].
T_ARRAY = 9
Sciter internal array, unit is [VALUE_UNIT_TYPE_ARRAY].
T_MAP = 10
Sciter internal array of key-value pairs.
T_FUNCTION = 11
Sciter internal function, holds its name and params.
T_BYTES = 12
Sciter internal array of bytes.
T_OBJECT = 13
Sciter internal object, unit is [VALUE_UNIT_TYPE_OBJECT].
T_DOM_OBJECT = 14
Sciter internal object.
T_RESOURCE = 15
Sciter-managed resource object.
T_RANGE = 16
N..M range as a 32-bit integer pair, units are zero.
T_DURATION = 17
Time duration as a float, in seconds or milliseconds (depends on the unit).
T_ANGLE = 18
Angle radians as a float, unit is [VALUE_UNIT_TYPE_ANGLE].
T_COLOR = 19
Color in ARGB format as a 32-bit number.
T_ENUM = 20
Sciter internal array of value-name pairs.
T_ASSET = 21
Sciter asset.
T_UNKNOWN = 22