[−][src]Enum sciter::graphics::LINE_CAP
Line drawing cap mode.
Variants
The ends of lines are squared off at the endpoints.
The ends of lines are squared off by adding a box with an equal width and half the height of the line's thickness.
The ends of lines are rounded.